# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['osint_tools',
 'osint_tools.api',
 'osint_tools.api.email',
 'osint_tools.api.email.gmail',
 'osint_tools.api.four_chan',
 'osint_tools.api.rss',
 'osint_tools.db',
 'osint_tools.db.mongo_db',
 'osint_tools.schemas',
 'osint_tools.schemas.rss']

package_data = \
{'': ['*']}

install_requires = \
['feedparser>=6.0.8,<7.0.0',
 'motor>=3.0.0,<4.0.0',
 'pydantic>=1.10.1,<2.0.0',
 'python-jose>=3.3.0,<4.0.0',
 'requests>=2.11']

setup_kwargs = {
    'name': 'osint-tools',
    'version': '0.1.5',
    'description': '',
    'long_description': '# Python library for parsing various API\'s\n\n\n\n\'\'\'python\nSynthesizing 8/10 solutions\n\n=======\n\nclass GoogleTrends:\n    def __init__(self):\n        pass\n\n    def get_trends(self, keyword, start_date, end_date, geo, cat, output):\n        url = f\'https://trends.google.com/trends/api/widgetdata/multiline/csv?req=%7B%22comparisonItem%22%3A%5B%7B%22keyword%22%3A%22{keyword}%22%2C%22geo%22%3A%22{geo}%22%2C%22time%22%3A%22{start_date}%20{end_date}%22%7D%5D%2C%22category%22%3A{cat}%2C%22property%22%3A%22%22%7D&token=APP6_UEAAAAAXZl5x5d5k5G8eW6aJy9aE9J1fQ8I4Wm1&tz=180\'\n        r = requests.get(url)\n        if output == \'csv\':\n            return r.text\n        elif output == \'json\':\n            return r.json()\n\n=======\n\n        def __init__(self):\n        self.url = \'https://trends.google.com/trends/api/explore\'\n        self.headers = {\n            \'authority\': \'trends.google.com\',\n            \'method\': \'GET\',\n            \'path\': \'/trends/api/explore\',\n            \'scheme\': \'https\',\n            \'accept\': \'*/*\',\n            \'accept-encoding\': \'gzip, deflate, br\',\n            \'accept-language\': \'en-US,en;q=0.9\',\n            \'cache-control\': \'no-cache\',\n            \'cookie\': \'NID=204=JcCkKjQ7B5f5U4x6U4Z6M0jKUu8M9k9DfzFyYKo7RzK0QaQxhPwZ3Gq3jK8ZVd9Xyf1S2QKl8H2u4D4mZ6U4V6U4Z6M0jKUu8M9k9DfzFyYKo7RzK0QaQxhPwZ3Gq3jK8ZVd9Xyf1S2QKl8H2u4D4mZ6U4V6U4Z6M0jKUu8M9k9DfzFyYKo7RzK0QaQxhPwZ3Gq3jK8ZVd9Xyf1S2QKl8H2u4D4mZ6U4V6U4Z6M0jKUu8M9k9DfzFyYKo7RzK0QaQxhPwZ3Gq3jK8ZVd9Xyf1S2QKl8H2u4D4mZ6U4V6U4Z6M0jKUu8M9k9DfzFyYKo7RzK0QaQxhPwZ3Gq3jK8ZVd9Xyf1S2QKl8H2u4D4mZ6U4V6U4Z6M0jKUu8M9k9\n\n=======\n\nclass GoogleTrends:\n    def __init__(self):\n        self.url = \'https://trends.google.com/trends/api/explore\'\n        self.params = {\n            \'hl\': \'en-US\',\n            \'tz\': 360,\n            \'req\': {\n                \'comparisonItem\': [\n                    {\n                        \'keyword\': \'bitcoin\',\n                        \'geo\': \'US\',\n                        \'time\': \'today 5-y\'\n                    }\n                ],\n                \'category\': 0,\n                \'property\': \'\'\n            },\n            \'token\': \'\',\n            \'tz\': 360\n        }\n\n    def get_trends(self, keyword, start_date, end_date, geo, cat, output):\n        self.params[\'req\'][\'comparisonItem\'][0][\'keyword\'] = keyword\n        self.params[\'req\'][\'comparisonItem\'][0][\'geo\'] = geo\n        self.params[\'req\'][\'comparisonItem\'][0][\'time\'] = f\'{start_date} {end_date}\'\n        self.params[\'req\'][\'category\'] = cat\n        self.params[\'req\'][\'property\'] = \'\'\n\n        r = requests.get(self.url, params=self.params)\n        if output == \'json\':\n            return r.json()\n        elif output == \'csv\':\n            pass\n        else:\n            return r.json()\n\n=======\n\nclass GoogleTrends:\n    def __init__(self):\n        self.url = \'https://trends.google.com/trends/api/dailytrends\'\n        self.headers = {\n            \'Connection\': \'keep-alive\',\n            \'Accept\': \'application/json, text/plain, */*\',\n            \'Sec-Fetch-Dest\': \'empty\',\n            \'X-Client-Data\': \'CI22yQEIo7bJAQjEtskBCKmdygEIqKPKAQi0p8oBCOKoygEI7KjKAQjxqMoBCL2oygEI8ajKAQ==\',\n            \'User-Agent\': \'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.107 Safari/537.36\',\n            \'Sec-Fetch-Site\': \'same-origin\',\n            \'Sec-Fetch-Mode\': \'cors\',\n            \'Referer\': \'https://trends.google.com/trends/explore?date=2015-01-01%202022-09-12&geo=US&q=bitcoin\',\n            \'Accept-Language\': \'en-US,en;q=0.9\',\n        }\n\n    def get_trends(self, keyword, start_date, end_date, geo, cat, output):\n        params = (\n            (\'hl\', \'en-US\'),\n            (\'tz\', \'-60\'),\n            (\'req\', \'{"comparisonItem":[{"keyword":"\'+keyword+\'","geo":"\'+geo+\'","time":"\'+start_date+\' \'+end_date+\'"},{"keyword":"\'+keyword+\'","geo":"\'+geo+\'","time":"today 5-y"}],"category":\'+str(cat)+\',"property":""}\'),\n            (\'tz\', \'-60\'),\n        )\n\n        response = requests.get(self.url, headers=self.headers, params=params)\n        if output == \'json\':\n            return response.json()\n        elif output == \'csv\':\n            return response.content\n        else:\n            print(\'invalid output format\')\n\n=======\n\n        def __init__(self):\n        self.url = \'https://trends.google.com/trends/api/explore\'\n        self.params = {\n            \'hl\': \'en-US\',\n            \'tz\': 360,\n            \'req\': {\'comparisonItem\': [{\'keyword\': \'bitcoin\', \'geo\': \'US\', \'time\': \'today 5-y\'}], \'category\': 0, \'property\': \'\'},\n            \'token\': \'TOKEN\',\n            \'tz\': 360\n        }\n        self.headers = {\n            \'authority\': \'trends.google.com\',\n            \'method\': \'GET\',\n            \'path\': \'/trends/api/explore?hl=en-US&tz=360&req=%7B%22comparisonItem%22%3A%5B%7B%22keyword%22%3A%22bitcoin%22%2C%22geo%22%3A%22US%22%2C%22time%22%3A%22today+5-y%22%7D%5D%2C%22category%22%3A0%2C%22property%22%3A%22%22%7D&token=TOKEN&tz=360\',\n            \'scheme\': \'https\',\n            \'accept\': \'application/json, text/javascript, */*; q=0.01\',\n            \'accept-encoding\': \'gzip, deflate, br\',\n            \'accept-language\': \'en-US,en;q=0.9\',\n            \'referer\': \'https://trends.google.com/trends/explore?date=2015-01-01%202022-09-12&geo=US&q=bitcoin\',\n            \'sec-ch-ua\': \'" Not A;Brand";v="99", "Chromium";v="90", "Google Chrome";v="90"\',\n            \'sec-ch-ua-mobile\': \'?0\',\n            \'sec-fetch-dest\': \'empty\',\n            \'sec-fetch-mode\': \'cors\',\n            \'sec-fetch-site\': \'same-origin\',\n            \'user-agent\': \'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.93 Safari/537.36\',\n            \'x-client-data\': \'CI22yQEIo7bJAQjEtskBCKmdygEIqK\n\n=======\n\nclass GoogleTrends:\n    def __init__(self):\n        self.url = \'https://trends.google.com/trends/api/explore\'\n        self.payload = {\n            \'hl\': \'en-US\',\n            \'tz\': 360,\n            \'req\': {\n                \'comparisonItem\': [\n                    {\n                        \'keyword\': \'\',\n                        \'geo\': \'\',\n                        \'time\': \'\'\n                    }\n                ],\n                \'category\': 0,\n                \'property\': \'\'\n            },\n            \'token\': \'\',\n            \'tz\': 360\n        }\n        self.headers = {\n            \'authority\': \'trends.google.com\',\n            \'accept\': \'application/json\',\n            \'x-client-data\': \'CIi2yQEIorbJAQjBtskBCKmdygEIqKPKAQioo8oBCO6oygEI7qjKAQ==\',\n            \'user-agent\': \'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.159 Safari/537.36\',\n            \'content-type\': \'application/x-www-form-urlencoded\',\n            \'origin\': \'https://trends.google.com\',\n            \'sec-fetch-site\': \'same-site\',\n            \'sec-fetch-mode\': \'cors\',\n            \'sec-fetch-dest\': \'empty\',\n            \'referer\': \'https://trends.google.com/trends/explore?date=2015-01-01%202022-09-12&geo=US&q=bitcoin\',\n            \'accept-language\': \'en-US,en;q=0.9\',\n        }\n\n    def get_trends(self, keyword, start_date, end_date, geo, cat, output=\'json\'):\n        self.payload[\'req\'][\'comparisonItem\'][0][\'keyword\'] = keyword\n        self.payload[\'req\'][\'comparisonItem\'][0][\'geo\'] = geo\n        self.payload[\'req\'][\'comparisonItem\'][0][\'time\'] = start_date + \' \' + end_date\n        self.payload[\'req\'][\'category\'] = cat\n        self.payload[\'req\'][\'property\'] = \'\'\n        response = requests.post(self.url, headers=self.headers, json=self.payload)\n        if output == \'json\':\n            return response.json()\n        else:\n            return response.content\n\n=======\n\nclass GoogleTrends:\n    def __init__(self):\n        self.url = \'https://trends.google.com/trends/api/explore\'\n        self.params = {\n            \'hl\':\'en-US\',\n            \'tz\':360,\n            \'req\':{\n                \'comparisonItem\':[\n                    {\n                        \'keyword\':\'bitcoin\',\n                        \'geo\':\'US\',\n                        \'time\':\'today 5-y\'\n                    }\n                ],\n                \'category\':0,\n                \'property\':\'\'\n            }\n        }\n\n    def get_trends(self, keyword, start_date, end_date, geo, cat, output):\n        self.params[\'req\'][\'comparisonItem\'][0][\'keyword\'] = keyword\n        self.params[\'req\'][\'comparisonItem\'][0][\'geo\'] = geo\n        self.params[\'req\'][\'comparisonItem\'][0][\'time\'] = f\'{start_date} {end_date}\'\n        self.params[\'req\'][\'category\'] = cat\n        r = requests.get(self.url, params=self.params)\n        if output == \'json\':\n            return r.json()\n        else:\n            return r.text\n\n=======\n\nclass GoogleTrends:\n    def __init__(self):\n        pass\n\n    def get_trends(self, keyword, start_date, end_date, geo, cat, output):\n        \'\'\'\n        keyword: keyword to search for\n        start_date: start date of the search\n        end_date: end date of the search\n        geo: country code\n        cat: category\n        output: format of the output (json or csv)\n        \'\'\'\n        # url to get the data\n        url = \'https://trends.google.com/trends/api/explore\'\n\n        # parameters to get the data\n        params = {\n            \'hl\': \'en-US\',\n            \'tz\': \'60\',\n            \'req\': {"comparisonItem":[{"keyword":keyword,"geo":geo,"time":start_date+\' \'+end_date}],"category":cat},\n            \'tz\': \'60\',\n        }\n\n        # request the data\n        r = requests.get(url, params=params).json()\n\n        # save the data as csv or json file\n        if output == \'csv\':\n            with open(\'trends.csv\', \'w\') as f:\n                f.write(r[\'default\'][\'timelineData\'])\n        elif output == \'json\':\n            return r\n\n\'\'\'',
    'author': 'Alexander Slessor',
    'author_email': 'alexjslessor@gmail.com.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
